==> apache-shardingsphere-5.5.2-src.zip: apache-shardingsphere-5.5.2-src-release/infra/common/src/main/java/org/apache/shardingsphere/infra/rule/PartialRuleUpdateSupported.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.infra.rule;

import org.apache.shardingsphere.infra.config.rule.RuleConfiguration;

/**
 * Partial rule update supported.
 * 
 * @param <T> rule configuration type
 */
public interface PartialRuleUpdateSupported<T extends RuleConfiguration> {
    
    /**
     * Update rule configuration.
     *
     * @param toBeUpdatedRuleConfig to be updated configuration
     */
    void updateConfiguration(T toBeUpdatedRuleConfig);
    
    /**
     * Partial update.
     *
     * @param toBeUpdatedRuleConfig to be updated configuration
     * @return update success or not
     */
    // TODO remove return value when support alter
    boolean partialUpdate(T toBeUpdatedRuleConfig);
}

==> apache-shardingsphere-5.5.3-src.zip: apache-shardingsphere-5.5.3-src-release/infra/common/src/main/java/org/apache/shardingsphere/infra/rule/PartialRuleUpdateSupported.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.infra.rule;

import org.apache.shardingsphere.infra.config.rule.RuleConfiguration;

/**
 * Partial rule update supported.
 * 
 * @param <T> rule configuration type
 */
public interface PartialRuleUpdateSupported<T extends RuleConfiguration> {
    
    /**
     * Update rule configuration.
     *
     * @param toBeUpdatedRuleConfig to be updated configuration
     */
    void updateConfiguration(T toBeUpdatedRuleConfig);
    
    /**
     * Partial update.
     *
     * @param toBeUpdatedRuleConfig to be updated configuration
     *
     * @return whether need refresh table schemas after rule configuration updated
     */
    boolean partialUpdate(T toBeUpdatedRuleConfig);
}
